==> wafwebaclcloudfront-2.21.0-sources.jar: software/amazon/awsconstructs/services/wafwebaclcloudfront/WafwebaclToCloudFrontProps.java <==
package software.amazon.awsconstructs.services.wafwebaclcloudfront;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.65.0 (build 7a02b7f)", date = "2022-08-26T21:12:57.468Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.wafwebaclcloudfront.$Module.class, fqn = "@aws-solutions-constructs/aws-wafwebacl-cloudfront.WafwebaclToCloudFrontProps")
@software.amazon.jsii.Jsii.Proxy(WafwebaclToCloudFrontProps.Jsii$Proxy.class)
public interface WafwebaclToCloudFrontProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The existing CloudFront instance that will be protected with the WAF web ACL.
     * <p>
     * This construct changes the CloudFront distribution by directly manipulating
     * the CloudFormation output, so this must be the Construct and cannot be
     * changed to the Interface (IDistribution)
     */
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.Distribution getExistingCloudFrontWebDistribution();

    /**
     * Existing instance of a WAF web ACL, an error will occur if this and props is set.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.wafv2.CfnWebACL getExistingWebaclObj() {
        return null;
    }

    /**
     * Optional user-provided props to override the default props for the AWS WAF web ACL.
     * <p>
     * Default: - Default properties are used.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.wafv2.CfnWebACLProps getWebaclProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link WafwebaclToCloudFrontProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WafwebaclToCloudFrontProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<WafwebaclToCloudFrontProps> {
        software.amazon.awscdk.services.cloudfront.Distribution existingCloudFrontWebDistribution;
        software.amazon.awscdk.services.wafv2.CfnWebACL existingWebaclObj;
        software.amazon.awscdk.services.wafv2.CfnWebACLProps webaclProps;

        /**
         * Sets the value of {@link WafwebaclToCloudFrontProps#getExistingCloudFrontWebDistribution}
         * @param existingCloudFrontWebDistribution The existing CloudFront instance that will be protected with the WAF web ACL. This parameter is required.
         *                                          This construct changes the CloudFront distribution by directly manipulating
         *                                          the CloudFormation output, so this must be the Construct and cannot be
         *                                          changed to the Interface (IDistribution)
         * @return {@code this}
         */
        public Builder existingCloudFrontWebDistribution(software.amazon.awscdk.services.cloudfront.Distribution existingCloudFrontWebDistribution) {
            this.existingCloudFrontWebDistribution = existingCloudFrontWebDistribution;
            return this;
        }

        /**
         * Sets the value of {@link WafwebaclToCloudFrontProps#getExistingWebaclObj}
         * @param existingWebaclObj Existing instance of a WAF web ACL, an error will occur if this and props is set.
         * @return {@code this}
         */
        public Builder existingWebaclObj(software.amazon.awscdk.services.wafv2.CfnWebACL existingWebaclObj) {
            this.existingWebaclObj = existingWebaclObj;
            return this;
        }

        /**
         * Sets the value of {@link WafwebaclToCloudFrontProps#getWebaclProps}
         * @param webaclProps Optional user-provided props to override the default props for the AWS WAF web ACL.
         * @return {@code this}
         */
        public Builder webaclProps(software.amazon.awscdk.services.wafv2.CfnWebACLProps webaclProps) {
            this.webaclProps = webaclProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WafwebaclToCloudFrontProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public WafwebaclToCloudFrontProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link WafwebaclToCloudFrontProps}
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WafwebaclToCloudFrontProps {
        private final software.amazon.awscdk.services.cloudfront.Distribution existingCloudFrontWebDistribution;
        private final software.amazon.awscdk.services.wafv2.CfnWebACL existingWebaclObj;
        private final software.amazon.awscdk.services.wafv2.CfnWebACLProps webaclProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.existingCloudFrontWebDistribution = software.amazon.jsii.Kernel.get(this, "existingCloudFrontWebDistribution", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.Distribution.class));
            this.existingWebaclObj = software.amazon.jsii.Kernel.get(this, "existingWebaclObj", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.wafv2.CfnWebACL.class));
            this.webaclProps = software.amazon.jsii.Kernel.get(this, "webaclProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.wafv2.CfnWebACLProps.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.existingCloudFrontWebDistribution = java.util.Objects.requireNonNull(builder.existingCloudFrontWebDistribution, "existingCloudFrontWebDistribution is required");
            this.existingWebaclObj = builder.existingWebaclObj;
            this.webaclProps = builder.webaclProps;
        }

        @Override
        public final software.amazon.awscdk.services.cloudfront.Distribution getExistingCloudFrontWebDistribution() {
            return this.existingCloudFrontWebDistribution;
        }

        @Override
        public final software.amazon.awscdk.services.wafv2.CfnWebACL getExistingWebaclObj() {
            return this.existingWebaclObj;
        }

        @Override
        public final software.amazon.awscdk.services.wafv2.CfnWebACLProps getWebaclProps() {
            return this.webaclProps;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("existingCloudFrontWebDistribution", om.valueToTree(this.getExistingCloudFrontWebDistribution()));
            if (this.getExistingWebaclObj() != null) {
                data.set("existingWebaclObj", om.valueToTree(this.getExistingWebaclObj()));
            }
            if (this.getWebaclProps() != null) {
                data.set("webaclProps", om.valueToTree(this.getWebaclProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-wafwebacl-cloudfront.WafwebaclToCloudFrontProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WafwebaclToCloudFrontProps.Jsii$Proxy that = (WafwebaclToCloudFrontProps.Jsii$Proxy) o;

            if (!existingCloudFrontWebDistribution.equals(that.existingCloudFrontWebDistribution)) return false;
            if (this.existingWebaclObj != null ? !this.existingWebaclObj.equals(that.existingWebaclObj) : that.existingWebaclObj != null) return false;
            return this.webaclProps != null ? this.webaclProps.equals(that.webaclProps) : that.webaclProps == null;
        }

        @Override
        public final int hashCode() {
            int result = this.existingCloudFrontWebDistribution.hashCode();
            result = 31 * result + (this.existingWebaclObj != null ? this.existingWebaclObj.hashCode() : 0);
            result = 31 * result + (this.webaclProps != null ? this.webaclProps.hashCode() : 0);
            return result;
        }
    }
}

==> wafwebaclcloudfront-2.71.0-sources.jar: software/amazon/awsconstructs/services/wafwebaclcloudfront/WafwebaclToCloudFrontProps.java <==
package software.amazon.awsconstructs.services.wafwebaclcloudfront;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.103.1 (build bef2dea)", date = "2024-09-27T01:37:06.062Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.wafwebaclcloudfront.$Module.class, fqn = "@aws-solutions-constructs/aws-wafwebacl-cloudfront.WafwebaclToCloudFrontProps")
@software.amazon.jsii.Jsii.Proxy(WafwebaclToCloudFrontProps.Jsii$Proxy.class)
public interface WafwebaclToCloudFrontProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The existing CloudFront instance that will be protected with the WAF web ACL.
     * <p>
     * This construct changes the CloudFront distribution by directly manipulating
     * the CloudFormation output, so this must be the Construct and cannot be
     * changed to the Interface (IDistribution)
     */
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.Distribution getExistingCloudFrontWebDistribution();

    /**
     * Existing instance of a WAF web ACL, an error will occur if this and props is set.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.wafv2.CfnWebACL getExistingWebaclObj() {
        return null;
    }

    /**
     * Optional user-provided props to override the default props for the AWS WAF web ACL.
     * <p>
     * Default: - Default properties are used.
     */
    default @org.jetbrains.annotations.Nullable java.lang.Object getWebaclProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link WafwebaclToCloudFrontProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WafwebaclToCloudFrontProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<WafwebaclToCloudFrontProps> {
        software.amazon.awscdk.services.cloudfront.Distribution existingCloudFrontWebDistribution;
        software.amazon.awscdk.services.wafv2.CfnWebACL existingWebaclObj;
        java.lang.Object webaclProps;

        /**
         * Sets the value of {@link WafwebaclToCloudFrontProps#getExistingCloudFrontWebDistribution}
         * @param existingCloudFrontWebDistribution The existing CloudFront instance that will be protected with the WAF web ACL. This parameter is required.
         *                                          This construct changes the CloudFront distribution by directly manipulating
         *                                          the CloudFormation output, so this must be the Construct and cannot be
         *                                          changed to the Interface (IDistribution)
         * @return {@code this}
         */
        public Builder existingCloudFrontWebDistribution(software.amazon.awscdk.services.cloudfront.Distribution existingCloudFrontWebDistribution) {
            this.existingCloudFrontWebDistribution = existingCloudFrontWebDistribution;
            return this;
        }

        /**
         * Sets the value of {@link WafwebaclToCloudFrontProps#getExistingWebaclObj}
         * @param existingWebaclObj Existing instance of a WAF web ACL, an error will occur if this and props is set.
         * @return {@code this}
         */
        public Builder existingWebaclObj(software.amazon.awscdk.services.wafv2.CfnWebACL existingWebaclObj) {
            this.existingWebaclObj = existingWebaclObj;
            return this;
        }

        /**
         * Sets the value of {@link WafwebaclToCloudFrontProps#getWebaclProps}
         * @param webaclProps Optional user-provided props to override the default props for the AWS WAF web ACL.
         * @return {@code this}
         */
        public Builder webaclProps(java.lang.Object webaclProps) {
            this.webaclProps = webaclProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WafwebaclToCloudFrontProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public WafwebaclToCloudFrontProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link WafwebaclToCloudFrontProps}
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WafwebaclToCloudFrontProps {
        private final software.amazon.awscdk.services.cloudfront.Distribution existingCloudFrontWebDistribution;
        private final software.amazon.awscdk.services.wafv2.CfnWebACL existingWebaclObj;
        private final java.lang.Object webaclProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.existingCloudFrontWebDistribution = software.amazon.jsii.Kernel.get(this, "existingCloudFrontWebDistribution", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.Distribution.class));
            this.existingWebaclObj = software.amazon.jsii.Kernel.get(this, "existingWebaclObj", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.wafv2.CfnWebACL.class));
            this.webaclProps = software.amazon.jsii.Kernel.get(this, "webaclProps", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.existingCloudFrontWebDistribution = java.util.Objects.requireNonNull(builder.existingCloudFrontWebDistribution, "existingCloudFrontWebDistribution is required");
            this.existingWebaclObj = builder.existingWebaclObj;
            this.webaclProps = builder.webaclProps;
        }

        @Override
        public final software.amazon.awscdk.services.cloudfront.Distribution getExistingCloudFrontWebDistribution() {
            return this.existingCloudFrontWebDistribution;
        }

        @Override
        public final software.amazon.awscdk.services.wafv2.CfnWebACL getExistingWebaclObj() {
            return this.existingWebaclObj;
        }

        @Override
        public final java.lang.Object getWebaclProps() {
            return this.webaclProps;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("existingCloudFrontWebDistribution", om.valueToTree(this.getExistingCloudFrontWebDistribution()));
            if (this.getExistingWebaclObj() != null) {
                data.set("existingWebaclObj", om.valueToTree(this.getExistingWebaclObj()));
            }
            if (this.getWebaclProps() != null) {
                data.set("webaclProps", om.valueToTree(this.getWebaclProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-wafwebacl-cloudfront.WafwebaclToCloudFrontProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WafwebaclToCloudFrontProps.Jsii$Proxy that = (WafwebaclToCloudFrontProps.Jsii$Proxy) o;

            if (!existingCloudFrontWebDistribution.equals(that.existingCloudFrontWebDistribution)) return false;
            if (this.existingWebaclObj != null ? !this.existingWebaclObj.equals(that.existingWebaclObj) : that.existingWebaclObj != null) return false;
            return this.webaclProps != null ? this.webaclProps.equals(that.webaclProps) : that.webaclProps == null;
        }

        @Override
        public final int hashCode() {
            int result = this.existingCloudFrontWebDistribution.hashCode();
            result = 31 * result + (this.existingWebaclObj != null ? this.existingWebaclObj.hashCode() : 0);
            result = 31 * result + (this.webaclProps != null ? this.webaclProps.hashCode() : 0);
            return result;
        }
    }
}
